@@ -6,21 +6,21 @@ from perceptor import models
 
 
 class SimulacraAesthetic(LossInterface):
-    def __init__(self, model_name="ViT-L/14", aesthetic_target=10):
+    def __init__(self, model_name="ViT-L-14", aesthetic_target=10):
         """
         Simulacra aesthetic loss based on clip linear regression probe that predicts the aesthetic rating of an image.
 
         Args:
             model_name (str): Name of CLIP model. Available models are:
-                - ViT-B/32
-                - ViT-B/16
-                - ViT-L/14
+                - ViT-B-32
+                - ViT-B-16
+                - ViT-L-14
                 - RN50
                 - RN101
                 - RN50x4
                 - RN50x16
                 - RN50x64
-                - ViT-L/14@336px
+                - ViT-L-14-336
             aesthetic_target (int): Target asthetic rating of the image (1-10).
         """
         super().__init__()
@@ -28,7 +28,7 @@ class SimulacraAesthetic(LossInterface):
             torch.as_tensor(aesthetic_target).float(), requires_grad=False
         )
         self.model = models.SimulacraAesthetic(model_name)
-        if model_name in ("ViT-L/14", "ViT-L/14@336px"):
+        if model_name in ("ViT-L-14", "ViT-L-14-336"):
             self.multiplier = 0.00001
         else:
             self.multiplier = 0.001
@@ -42,5 +42,5 @@ class SimulacraAesthetic(LossInterface):
 
 
 def test_simulacra_aesthetic_loss():
-    loss = SimulacraAesthetic().cuda()
+    loss = SimulacraAesthetic("ViT-B-32").cuda()
     loss(torch.randn(1, 3, 256, 256).cuda())
